package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;

import com.chelvc.cloud.admin.param.MobileParam;
import com.chelvc.cloud.uc.api.AuthorizeClient;
import com.chelvc.cloud.uc.api.model.Authorization;
import com.chelvc.cloud.uc.api.param.AuthorizeParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.oauth.annotation.Authorize;
import com.chelvc.framework.sms.CaptchaSmsHandler;
import com.chelvc.framework.sms.SmsSession;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 登陆接口
 *
 * @author Woody
 * @date 2024/1/31
 */
@RestController
@ResponseWrapping
@Authorize(enabled = false)
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class AuthorizeController {
    private final AuthorizeClient authorizeClient;
    private final CaptchaSmsHandler captchaSmsHandler;

    /**
     * 短信登陆
     *
     * @param param 登陆参数
     * @return 认证信息
     */
    @Authorize(enabled = false)
    @PostMapping("/login/sms")
    public Authorization loginWithSms(@RequestBody @Valid AuthorizeParam.Sms param) {
        return this.authorizeClient.authorize(param);
    }

    /**
     * 发送短信登陆验证码
     *
     * @param param 手机号参数
     * @return 短信会话信息
     */
    @Authorize(enabled = false)
    @PostMapping("/login/sms/captcha")
    public SmsSession sendCaptcha(@RequestBody @Valid MobileParam param) {
        return this.captchaSmsHandler.send(param.getMobile());
    }

    /**
     * 账号密码登陆
     *
     * @param param 登陆参数
     * @return 认证信息
     */
    @Authorize(enabled = false)
    @PostMapping("/login/password")
    public Authorization loginWithPassword(@RequestBody @Valid AuthorizeParam.Password param) {
        return this.authorizeClient.authorize(param);
    }

    /**
     * 令牌刷新
     *
     * @param param 刷新参数
     * @return 认证信息
     */
    @PostMapping("/token/refresh")
    public Authorization refreshToken(@RequestBody @Valid AuthorizeParam.Refresh param) {
        return this.authorizeClient.authorize(param);
    }

    /**
     * 退出登陆
     *
     * @param param 认证参数
     */
    @PostMapping("/logout")
    public void logout(@RequestBody @Valid AuthorizeParam param) {
        this.authorizeClient.logout(param);
    }
}
