package com.chelvc.cloud.admin.controller;

import com.chelvc.cloud.vehicle.api.dto.CarouselImagesDTO;
import com.chelvc.cloud.vehicle.api.param.CarouselImagesModifyParam;
import com.chelvc.cloud.vehicle.api.param.CarouselImagesPagingParam;
import com.chelvc.cloud.vehicle.api.service.CarouselImagesService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.Min;

/**
 * 轮播图接口
 *
 * @author liude
 * @Date 2023/12/29
 **/
@Validated
@RestController
@ResponseWrapping
public class CarouselImagesController {
    @DubboReference
    private CarouselImagesService carouselImagesService;

    /**
     * 新增轮播图
     *
     * @param param 新增参数
     * @return 轮播图主键
     */
    @PostMapping("/carouselImages")
    public Long addCarouselImages(@RequestBody @Valid CarouselImagesModifyParam param) {
        return this.carouselImagesService.addCarouselImages(param);
    }

    /**
     * 修改轮播图
     *
     * @param id    轮播图主键
     * @param param 修改参数
     */
    @PutMapping("/carouselImages/{id}")
    public void updateCarouselImages(@PathVariable("id") @Min(value = 1, message = "轮播图主键不能小于1") Long id,
                               @RequestBody @Valid CarouselImagesModifyParam param) {
        this.carouselImagesService.updateCarouselImages(id, param);
    }

    /**
     * 删除轮播图
     *
     * @param id    轮播图主键
     */
    @PutMapping("/carouselImages/delete/{id}")
    public void deleteCarouselImages(@PathVariable("id") @Min(value = 1, message = "轮播图主键不能小于1") Long id) {
        this.carouselImagesService.deleteCarouselImages(id);
    }

    /**
     * 查询轮播图分页
     *
     * @param param 查询参数
     * @return 轮播图分页信息
     */
    @GetMapping("/carouselImages/paging")
    public Pagination<CarouselImagesDTO> getCarouselImagesPaging(@Valid CarouselImagesPagingParam param) {
        return this.carouselImagesService.getCarouselImagesPaging(param);
    }
}
