package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.api.dto.CategoryDTO;
import com.chelvc.cloud.vehicle.api.param.CategoryModifyParam;
import com.chelvc.cloud.vehicle.api.param.CategoryPagingParam;
import com.chelvc.cloud.vehicle.api.service.CategoryService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 分类接口
 *
 * @author 七仔
 * @Date 2023/4/4
 **/
@Validated
@RestController
@ResponseWrapping
public class CategoryController {
    @DubboReference
    private CategoryService categoryService;

    /**
     * 新增分类
     *
     * @param param 新增参数
     * @return 分类主键
     */
    @PostMapping("/category")
    public Long addCategory(@RequestBody @Valid CategoryModifyParam param) {
        return this.categoryService.addCategory(param);
    }

    /**
     * 修改分类
     *
     * @param id    分类主键
     * @param param 修改参数
     */
    @PutMapping("/category/{id}")
    public void updateCategory(@PathVariable("id") @Min(value = 1, message = "分类主键不能小于1") Long id,
                               @RequestBody @Valid CategoryModifyParam param) {
        this.categoryService.updateCategory(id, param);
    }

    /**
     * 查询分类分页
     *
     * @param param 查询参数
     * @return 分类分页信息
     */
    @GetMapping("/category/paging")
    public Pagination<CategoryDTO> getCategoryPaging(@Valid CategoryPagingParam param) {
        return this.categoryService.getCategoryPaging(param);
    }


    /**
     * 删除分类
     *
     * @param id    分类主键
     */
    @GetMapping("/category/delete/{id}")
    public void deleteCategory(@PathVariable("id") @Min(value = 1, message = "分类主键不能小于1") Long id) {
        this.categoryService.deleteCategory(id);
    }

    /**
     * 获取分类列表
     *
     * @return 分类信息列表
     */
    @GetMapping("/categories")
    public List<CategoryDTO> listCategories() {
        return this.categoryService.listActiveCategories();
    }

    /**
     * 获取一级分类列表
     *
     * @return 分类信息列表
     */
    @GetMapping("/getRootCategories")
    public List<CategoryDTO> getRootCategories() {
        return this.categoryService.getRootCategories();
    }
}
