package com.chelvc.cloud.admin.controller;
import com.chelvc.cloud.vehicle.api.dto.GoodsDTO;
import com.chelvc.cloud.vehicle.api.param.GoodsModifyParam;
import com.chelvc.cloud.vehicle.api.param.GoodsPagingParam;
import com.chelvc.cloud.vehicle.api.service.GoodsService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.Min;

/**
 * 商品接口
 *
 * @author liude
 * @Date 2023/8/29
 **/
@Validated
@RestController
@ResponseWrapping
public class GoodsController {
    @DubboReference
    private GoodsService goodsService;

    /**
     * 新增商品
     *
     * @param param 新增参数
     * @return 商品主键
     */
    @PostMapping("/goods")
    public Long addGoods(@RequestBody @Valid GoodsModifyParam param) {
        return this.goodsService.addGoods(param);
    }

    /**
     * 修改商品
     *
     * @param id    商品主键
     * @param param 修改参数
     */
    @PutMapping("/goods/{id}")
    public void updateGoods(@PathVariable("id") @Min(value = 1, message = "商品主键不能小于1") Long id,
                               @RequestBody @Valid GoodsModifyParam param) {
        this.goodsService.updateGoods(id, param);
    }

    /**
     * 删除商品
     *
     * @param id    商品主键
     */
    @PutMapping("/goods/delete/{id}")
    public void deleteGoods(@PathVariable("id") @Min(value = 1, message = "商品主键不能小于1") Long id) {
        this.goodsService.deleteGoods(id);
    }

    /**
     * 查询商品分页
     *
     * @param param 查询参数
     * @return 商品分页信息
     */
    @GetMapping("/goods/paging")
    public Pagination<GoodsDTO> getGoodsPaging(@Valid GoodsPagingParam param) {
        return this.goodsService.getGoodsPaging(param);
    }
}
