package com.chelvc.cloud.admin.controller;

import java.util.List;
import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.uc.api.dto.MenuDTO;
import com.chelvc.cloud.uc.api.param.MenuModifyParam;
import com.chelvc.cloud.uc.api.param.MenuQueryParam;
import com.chelvc.cloud.uc.api.service.MenuService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 菜单接口
 *
 * @author Woody
 * @date 2021/10/20
 */
@Validated
@RestController
@ResponseWrapping
public class MenuController {
    @DubboReference
    private MenuService menuService;

    /**
     * 新增菜单
     *
     * @param param 新增参数
     * @return 菜单主键
     */
    @PostMapping("/menu")
    public Long addMenu(@RequestBody @Valid MenuModifyParam param) {
        return this.menuService.addMenu(param);
    }

    /**
     * 修改菜单
     *
     * @param id    菜单主键
     * @param param 修改参数
     */
    @PutMapping("/menu/{id}")
    public void updateMenu(@PathVariable("id") @Min(value = 1, message = "菜单主键不能小于1") Long id,
                           @RequestBody @Valid MenuModifyParam param) {
        this.menuService.updateMenu(id, param);
    }

    /**
     * 获取菜单信息
     *
     * @param id 菜单主键
     * @return 菜单信息
     */
    @GetMapping("/menu/{id}")
    public MenuDTO getMenu(@PathVariable("id") @Min(value = 1, message = "菜单主键不能小于1") Long id) {
        return this.menuService.getMenu(id);
    }

    /**
     * 查询菜单树列表
     *
     * @param param 查询参数
     * @return 菜单树列表
     */
    @GetMapping("/menu/trees")
    public List<MenuDTO> listMenuTrees(@Valid MenuQueryParam param) {
        return this.menuService.listMenuTrees(param);
    }
}
