package com.chelvc.cloud.admin.controller;

import com.chelvc.cloud.vehicle.api.dto.MerchantAuthDTO;
import com.chelvc.cloud.vehicle.api.param.MerchantAuthModifyParam;
import com.chelvc.cloud.vehicle.api.param.MerchantAuthPagingParam;
import com.chelvc.cloud.vehicle.api.service.MerchantAuthService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import javax.validation.Valid;
import javax.validation.constraints.Min;

/**
 * 商家认证接口
 *
 * @author liude
 * @date 2023/12/13
 */
@Validated
@RestController
@ResponseWrapping
public class MerchantAuthController {
    @DubboReference
    private MerchantAuthService merchantAuthService;
    /**
     * 查询商家商家认证分页
     *
     * @param param 查询参数
     * @return 商家商家认证分页信息
     */
    @GetMapping("/merchantAuth/paging")
    public Pagination<MerchantAuthDTO> getMerchantAuthPaging(@Valid MerchantAuthPagingParam param) {
        return this.merchantAuthService.getMerchantAuthPaging(param);
    }

    /**
     * 商家认证审核
     *
     * @param id    商家商家认证主键
     * @param state 0-拒绝 1-通过
     */
    @GetMapping("/certificationAudit/{id}")
    public void certificationAudit(@PathVariable("id") @Min(value = 1, message = "商家主键不能小于1") Long id,
                                   String state ) {
        this.merchantAuthService.certificationAudit(id, state);
    }
}
