package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

import com.chelvc.cloud.vehicle.api.dto.RankAwardConfigDTO;
import com.chelvc.cloud.vehicle.api.param.AddRankAwardConfigParams;
import com.chelvc.cloud.vehicle.api.param.EditRankAwardConfigParams;
import com.chelvc.cloud.vehicle.api.param.QueryRankAwardConfigParam;
import com.chelvc.cloud.vehicle.api.service.RankAwardConfigService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.model.Paging;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 排行榜奖励配置
 */

@Validated
@RestController
@ResponseWrapping
@PreAuthorize("isScope('EMPLOYEE')")
public class RankAwardConfigController {

    @DubboReference
    private RankAwardConfigService rankAwardConfigService;

    /**
     * 新增
     *
     * @param param 新增参数
     */
    @PostMapping("/rank-award/add")
    public void add(@RequestBody @Valid AddRankAwardConfigParams param) {
        param.setUserId(SessionContextHolder.getId());
        this.rankAwardConfigService.add(param);
    }

    /**
     * 修改
     *
     * @param param 修改参数
     */
    @PutMapping("/rank-award/edit")
    public void edit(@RequestBody @Valid EditRankAwardConfigParams param) {
        param.setUserId(SessionContextHolder.getId());
        this.rankAwardConfigService.edit(param);
    }

    /**
     * 删除
     *
     * @param id
     */
    @DeleteMapping("/rank-award/del/{id}")
    public void delete(@NotNull(message = "主键不能为空") @PathVariable Long id) {
        this.rankAwardConfigService.delete(id, SessionContextHolder.getId());
    }

    /**
     * 查询列表
     *
     * @param param
     * @param page
     * @author igl
     * @date 2024/2/23 17:25
     */
    @GetMapping("/rank-award/list")
    public Pagination<RankAwardConfigDTO> list(QueryRankAwardConfigParam param, Paging page) {
        return this.rankAwardConfigService.queryPageList(param, page.getNumber(), page.getSize());
    }
}
