package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;

import com.chelvc.cloud.vehicle.api.dto.RankAwardRecordDTO;
import com.chelvc.cloud.vehicle.api.param.HandRankAwardParam;
import com.chelvc.cloud.vehicle.api.param.QueryRankAwardRecordParam;
import com.chelvc.cloud.vehicle.api.service.RankAwardRecordService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.model.Paging;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 排行榜派奖记录
 */
@Validated
@RestController
@ResponseWrapping
@PreAuthorize("isScope('EMPLOYEE')")
public class RankAwardRecordController {

    @DubboReference
    RankAwardRecordService rankAwardRecordService;

    /**
     * 查询列表
     *
     * @param param
     * @param page
     * @author igl
     * @date 2024/2/23 17:25
     */
    @GetMapping("/rank-award-record/list")
    public Pagination<RankAwardRecordDTO> list(QueryRankAwardRecordParam param, Paging page) {
        return this.rankAwardRecordService.queryPageList(param, page.getNumber(), page.getSize());
    }

    /**
     * 手动发奖
     *
     * @param param
     * @author igl
     * @date 2024/2/23 17:25
     */
    @PostMapping("/hand-out/prizes")
    public void handOutPrize(@RequestBody @Valid HandRankAwardParam param) {
        this.rankAwardRecordService.handOutPrize(param);
    }
}
