package com.chelvc.cloud.admin.controller;

import java.util.List;
import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.uc.api.dto.RoleDTO;
import com.chelvc.cloud.uc.api.dto.RoleDetailDTO;
import com.chelvc.cloud.uc.api.param.RoleModifyParam;
import com.chelvc.cloud.uc.api.param.RolePagingParam;
import com.chelvc.cloud.uc.api.service.RoleService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 角色接口
 *
 * @author Woody
 * @date 2021/10/20
 */
@Validated
@RestController
@ResponseWrapping
public class RoleController {
    @DubboReference
    private RoleService roleService;

    /**
     * 新增角色
     *
     * @param param 新增参数
     * @return 角色主键
     */
    @PostMapping("/role")
    public Long addRole(@RequestBody @Valid RoleModifyParam param) {
        return this.roleService.addRole(param);
    }

    /**
     * 修改角色
     *
     * @param id    角色主键
     * @param param 修改参数
     */
    @PutMapping("/role/{id}")
    public void updateRole(@PathVariable("id") @Min(value = 1, message = "角色主键不能小于1") Long id,
                           @RequestBody @Valid RoleModifyParam param) {
        this.roleService.updateRole(id, param);
    }

    /**
     * 获取角色信息
     *
     * @param id 角色主键
     * @return 角色信息
     */
    @GetMapping("/role/{id}/detail")
    public RoleDetailDTO getRoleDetail(@PathVariable("id") @Min(value = 1, message = "角色主键不能小于1") Long id) {
        return this.roleService.getRoleDetail(id);
    }

    /**
     * 获取启用角色列表
     *
     * @return 角色列表信息
     */
    @GetMapping("/role/enables")
    public List<RoleDTO> listEnableRoles() {
        return this.roleService.listEnableRoles();
    }

    /**
     * 查询角色分页
     *
     * @param param 查询参数
     * @return 角色分页信息
     */
    @GetMapping("/role/paging")
    public Pagination<RoleDTO> getRolePaging(@Valid RolePagingParam param) {
        return this.roleService.getRolePaging(param);
    }
}
